@@ -48,7 +48,10 @@ use core::{
 	slice,
 };
 
-use wyz::pipe::Pipe;
+use wyz::pipe::{
+	Pipe,
+	PipeRef,
+};
 
 /** A frozen heap-allocated buffer of individual bits.
 
@@ -377,6 +380,43 @@ where
 		unsafe { slice::from_raw_parts_mut(base, elts) }
 	}
 
+	/// Sets the uninitialized bits of the vector to a fixed value.
+	///
+	/// This method modifies all bits in the allocated buffer that are outside
+	/// the `self.as_bitslice()` view so that they have a consistent value. This
+	/// can be used to zero the uninitialized memory so that when viewed as a
+	/// raw memory slice, bits outside the live region have a predictable value.
+	///
+	/// # Examples
+	///
+	/// ```rust
+	/// use bitvec::prelude::*;
+	///
+	/// let mut bb = BitBox::new(&220u8.view_bits::<Lsb0>()[.. 4]);
+	/// assert_eq!(bb.count_ones(), 2);
+	/// assert_eq!(bb.as_slice(), &[220u8]);
+	///
+	/// bb.set_uninitialized(false);
+	/// assert_eq!(bb.as_slice(), &[12u8]);
+	///
+	/// bb.set_uninitialized(true);
+	/// assert_eq!(bb.as_slice(), &[!3u8]);
+	/// ```
+	#[inline]
+	pub fn set_uninitialized(&mut self, value: bool) {
+		let head = self.bitptr().head().value() as usize;
+		let tail = head + self.len();
+		let elts = self.bitptr().elements() * T::Mem::BITS as usize;
+		let mut bp = self.bitptr();
+		unsafe {
+			bp.set_head(BitIdx::ZERO);
+			bp.set_len(elts);
+			let bits = bp.to_bitslice_mut::<O>();
+			bits.get_unchecked_mut(.. head).set_all(value);
+			bits.get_unchecked_mut(tail ..).set_all(value);
+		}
+	}
+
 	#[inline]
 	pub(crate) fn bitptr(&self) -> BitPtr<T> {
 		self.pointer.as_ptr().pipe(BitPtr::from_bitslice_ptr_mut)
@@ -407,20 +447,11 @@ where
 	/// of the `Box<[T::Mem]>` temporary view.
 	fn with_box<F, R>(&mut self, func: F) -> R
 	where F: FnOnce(&mut ManuallyDrop<Box<[T::Mem]>>) -> R {
-		let mut bitptr = self.bitptr();
-
-		let mut boxed = self
-			.as_mut_slice()
+		self.as_mut_slice()
 			.pipe(|s| s as *mut [T] as *mut [T::Mem])
 			.pipe(|raw| unsafe { Box::from_raw(raw) })
-			.pipe(ManuallyDrop::new);
-		let out = func(&mut boxed);
-
-		unsafe {
-			bitptr.set_pointer(boxed.as_ptr() as *mut T);
-		}
-		self.pointer = bitptr.to_nonnull();
-		out
+			.pipe(ManuallyDrop::new)
+			.pipe_mut(func)
 	}
 }
 
